import { type ZodSchema, type infer as Infer, type SafeParseReturnType } from 'zod';
import { type ServiceInterface } from '../Interface/ServiceInterface.js';
export declare class ZodSchemaValidatedService<TypePayloadSchema extends ZodSchema, TypeResponseSchema extends ZodSchema> implements ServiceInterface<Infer<TypePayloadSchema>, SafeParseReturnType<any, Infer<TypeResponseSchema>>> {
    private readonly payloadSchema;
    private readonly responseSchema;
    private readonly service;
    /**
     * Constructor.
     *
     * @param {TypePayloadSchema} payloadSchema - The Zod schema for the input data
     * @param {TypeResponseSchema} responseSchema - The Zod schema for the output data
     * @param {ServiceInterface<Infer<TypePayloadSchema>, Infer<TypeResponseSchema>>} service - The service to wrap
     */
    constructor(payloadSchema: TypePayloadSchema, responseSchema: TypeResponseSchema, service: ServiceInterface<Infer<TypePayloadSchema>, Infer<TypeResponseSchema>>);
    /**
     * Executes the service logic after validating the input payload and the response.
     *
     * @param {Infer<TypePayloadSchema>} payload - The input payload for the service
     * @returns {Promise<SafeParseReturnType<any, Infer<TypeResponseSchema>>>} - The Zod validation result for the response
     */
    execute(payload: Infer<TypePayloadSchema>): Promise<SafeParseReturnType<any, Infer<TypeResponseSchema>>>;
}
